#!/bin/sh
glilang=en

echo
if [ "$glilang" == "es" ]; then
    echo "Interfaz de la Biblioteca Digital Greenstone (Greenstone Librarian Interface - GLI)"
    echo "Copyright (C) 2004, New Zealand Digital Library Project, University Of Waikato"
    echo "La Interfaz de la Biblioteca Digital Greenstone NO INCLUYE ABSOLUTAMENTE NINGUNA GARANTA."
    echo "Para mayor informacin vea los trminos de la licencia en LICENSE.txt"
    echo "Este es un software abierto, por lo que lo invitamos a que lo distribuya de forma gratuita"
elif [ "$glilang" == "fr" ]; then
    echo "Interface du Bibliothcaire Greenstone (Greenstone Librarian Interface - GLI)"
    echo "Copyright (C) 2004, New Zealand Digital Library Project, University Of Waikato"
    echo "GLI est fourni sans AUCUNE GARANTIE; pour des dtails, voir LICENSE.txt"
    echo "Ceci est un logiciel libre, et vous tes invit  le redistribuer"
elif [ "$glilang" == "ru" ]; then
    echo "  Greenstone (Greenstone Librarian Interface - GLI)"
    echo "Copyright (C) 2004, New Zealand Digital Library Project, University Of Waikato"
    echo "     ;  .   LICENSE.TXT"
    echo " -         "
else
    echo "Greenstone Librarian Interface (GLI)"
    echo "Copyright (C) 2004, New Zealand Digital Library Project, University Of Waikato"
    echo "GLI comes with ABSOLUTELY NO WARRANTY; for details see LICENSE.txt"
    echo "This is free software, and you are welcome to redistribute it"
fi
echo

##  -------- Compile the Greenstone Librarian Interface --------

## ---- Check Javac exists ----
javacpath=

# Some users may set the above line manually
if [ "$javacpath" == "" ]; then

    # If it is set, use the JAVA_HOME environment variable
    if [ "$JAVA_HOME" != "" ]; then
	javacpath="$JAVA_HOME/bin/javac"

    # Check if Javac is on the search path
    else
	javacpath=`which javac 2> /dev/null`
    fi
fi

# Check that a Javac executable has been found
if [ "$glilang" == "es" ]; then
    echo "Revisando Javac: $javacpath"
elif [ "$glilang" == "fr" ]; then
    echo "Vrification de Javac: $javacpath"
elif [ "$glilang" == "ru" ]; then
    echo " Javac: $javacpath"
else
    echo "Checking Javac: $javacpath"
fi
if [ ! -x "$javacpath" ]; then
    echo
    if [ "$glilang" == "es" ]; then
	echo "No se pudo localizar una versin apropiada de Javac."
	echo "Por favor instale una nueva versin del Kit de Desarrollo de"
	echo "Software Java (versin 1.4 o posterior) y ejecute nuevamente"
	echo "este guin."
    elif [ "$glilang" == "fr" ]; then
	echo "Une version approprie de Javac n'a pas pu tre localise."
	echo "Veuillez installer une nouvelle version de Java SDK (version 1.4 ou"
	echo "plus rcente) et redmarrez ce script."
    elif [ "$glilang" == "ru" ]; then
	echo "      Javac."
	echo ",    Java SDK ( 1.4  "
	echo ")    ."
    else
	echo "Failed to locate an appropriate version of Javac. You must install a"
	echo "Java Development Kit (version 1.4 or greater) before compiling the"
	echo "Greenstone Librarian Interface."
    fi
    exit 1
fi

# Check that the version of javac is new enough (1.4.0 or higher) to compile the GLI
javacOK=`$javacpath -target 1.4 2>&1`
if [ ! "$javacOK" = "" ]; then
    # Special code for javac 1.4.2, since it complains about "no source files"
    javacOK142=`$javacpath -target 1.4 2>&1 | grep "javac: no source files"`
    # Special code for javac 1.5, since it is different again
    javacOK15=`$javacpath -target 1.5 2>&1 | grep "javac: no source files"`
    if [ "$javacOK142" = "" ] && [ "$javacOK15" = "" ]; then
	echo
	if [ "$glilang" == "es" ]; then
	    echo "La versin del Kit de Desarrollo de Software de Java (SDK por "
	    echo "sus siglas en ingls) que usted tiene instalada es demasiado "
	    echo "vieja para poder compilar la Interfaz de la Biblioteca Digital "
	    echo "Greenstone. Por favor instale una nueva versin del Kit de "
	    echo "Desarrollo de Software Java (versin 1.4 o posterior) y ejecute "
	    echo "nuevamente este guin."
	elif [ "$glilang" == "fr" ]; then
	    echo "La version de Java Development Kit que vous avez installe est trop"
	    echo "vieille pour compiler Greenstone Librarian Interface. Veuillez "
	    echo "installer une nouvelle version de Java SDK (version 1.4 ou plus"
	    echo "rcente) et redmarrez ce script."
	elif [ "$glilang" == "ru" ]; then
	    echo " Java Development Kit,   ,  ,"
	    echo "      Greenstone."
	    echo ",    Java SDK ( 1.4  "
	    echo ")    ."
	else
	    echo "The version of the Java Development Kit you have installed is too old"
	    echo "to compile the Greenstone Librarian Interface. Please install a new"
	    echo "version of the Java SDK (version 1.4 or newer) and rerun this script."
	fi
	exit 1
    fi
fi


## ---- Compile the GLI ----
echo

# If a file has been specified at the command-line, just compile that file
if [ ! "x$*" = "x" ] ; then
    if [ "$glilang" == "es" ]; then
	echo "Compilando $* y clases dependientes..."
    elif [ "$glilang" == "fr" ]; then
	echo "Compilation de $* et des classes dpendantes,,,"
    elif [ "$glilang" == "ru" ]; then
	echo " $*   ..."
    else
	echo "Compiling $* and dependent classes..."
    fi

    $javacpath -deprecation -d classes/ -sourcepath src/ -classpath classes/:lib/apache.jar:lib/qfslib.jar:lib/mail.jar:lib/activation.jar $*

    if [ "$glilang" == "es" ]; then
	echo "Hecho!"
    elif [ "$glilang" == "fr" ]; then
	echo "Termin!"
    elif [ "$glilang" == "ru" ]; then
	echo "!"
    else
	echo "Done!"
    fi
    exit 0
fi

# Otherwise compile the lot...
if [ "$glilang" == "es" ]; then
    echo "Compilando la Interfaz de la Biblioteca Digital Greenstone..."
elif [ "$glilang" == "fr" ]; then
    echo "Compilation de Greenstone Librarian Interface,,,"
elif [ "$glilang" == "ru" ]; then
    echo "   Greenstone..."
else
    echo "Compiling the Greenstone Librarian Interface..."
fi

$javacpath -deprecation -d classes/ -sourcepath src/ -classpath classes/:lib/apache.jar:lib/qfslib.jar:lib/mail.jar:lib/activation.jar src/org/greenstone/gatherer/*.java
$javacpath -deprecation -d classes/ -sourcepath src/ -classpath classes/:lib/apache.jar:lib/qfslib.jar:lib/mail.jar:lib/activation.jar src/org/greenstone/gatherer/cdm/*.java
$javacpath -deprecation -d classes/ -sourcepath src/ -classpath classes/:lib/apache.jar:lib/qfslib.jar:lib/mail.jar:lib/activation.jar src/org/greenstone/gatherer/collection/*.java
$javacpath -deprecation -d classes/ -sourcepath src/ -classpath classes/:lib/apache.jar:lib/qfslib.jar:lib/mail.jar:lib/activation.jar src/org/greenstone/gatherer/feedback/*.java
$javacpath -deprecation -d classes/ -sourcepath src/ -classpath classes/:lib/apache.jar:lib/qfslib.jar:lib/mail.jar:lib/activation.jar src/org/greenstone/gatherer/file/*.java
$javacpath -deprecation -d classes/ -sourcepath src/ -classpath classes/:lib/apache.jar:lib/qfslib.jar:lib/mail.jar:lib/activation.jar src/org/greenstone/gatherer/gems/*.java
$javacpath -deprecation -d classes/ -sourcepath src/ -classpath classes/:lib/apache.jar:lib/qfslib.jar:lib/mail.jar:lib/activation.jar src/org/greenstone/gatherer/gui/*.java
$javacpath -deprecation -d classes/ -sourcepath src/ -classpath classes/:lib/apache.jar:lib/qfslib.jar:lib/mail.jar:lib/activation.jar src/org/greenstone/gatherer/gui/border/*.java
$javacpath -deprecation -d classes/ -sourcepath src/ -classpath classes/:lib/apache.jar:lib/qfslib.jar:lib/mail.jar:lib/activation.jar src/org/greenstone/gatherer/gui/metaaudit/*.java
$javacpath -deprecation -d classes/ -sourcepath src/ -classpath classes/:lib/apache.jar:lib/qfslib.jar:lib/mail.jar:lib/activation.jar src/org/greenstone/gatherer/gui/tree/*.java
$javacpath -deprecation -d classes/ -sourcepath src/ -classpath classes/:lib/apache.jar:lib/qfslib.jar:lib/mail.jar:lib/activation.jar src/org/greenstone/gatherer/metadata/*.java
$javacpath -deprecation -d classes/ -sourcepath src/ -classpath classes/:lib/apache.jar:lib/qfslib.jar:lib/mail.jar:lib/activation.jar src/org/greenstone/gatherer/shell/*.java
$javacpath -deprecation -d classes/ -sourcepath src/ -classpath classes/:lib/apache.jar:lib/qfslib.jar:lib/mail.jar:lib/activation.jar src/org/greenstone/gatherer/util/*.java

if [ "$glilang" == "es" ]; then
    echo "Hecho!"
elif [ "$glilang" == "fr" ]; then
    echo "Termin!"
elif [ "$glilang" == "ru" ]; then
    echo "!"
else
    echo "Done!"
fi
